Downloader
----------

Problematic
^^^^^^^^^^^

How can we easily download one of our static files ?

Documentation
^^^^^^^^^^^^^

.. automodule:: PyFunceble.downloader
   :members:
   :private-members:

:code:`DownloaderBase()`
""""""""""""""""""""""""

.. autoclass:: PyFunceble.downloader.base.DownloaderBase
    :members:
    :private-members:

:code:`ConfigDownloader()`
""""""""""""""""""""""""""

.. autoclass:: PyFunceble.downloader.config.ConfigDownloader
    :members:
    :private-members:

:code:`DirectoryStructureDownloader()`
""""""""""""""""""""""""""""""""""""""

.. autoclass:: PyFunceble.downloader.directory_structure.DirectoryStructureDownloader
    :members:
    :private-members:

:code:`IANADownloader()`
""""""""""""""""""""""""

.. autoclass:: PyFunceble.downloader.iana.IANADownloader
    :members:
    :private-members:

:code:`IPv4ReputationDownloader()`
""""""""""""""""""""""""""""""""""

.. autoclass:: PyFunceble.downloader.ipv4_reputation.IPv4ReputationDownloader
    :members:
    :private-members:

:code:`PublicSuffixDownloader()`
""""""""""""""""""""""""""""""""

.. autoclass:: PyFunceble.downloader.publicsuffix.PublicSuffixDownloader
    :members:
    :private-members: